@@ -58,12 +58,12 @@ class CWTask(Task):
 
 
 class CWCelery(Celery):
-    task_cls = 'cubicweb_celery:CWTask'
+    task_cls = "cubicweb_celery:CWTask"
 
     defaults = {
-        'task_serializer': 'json',
-        'result_serializer': 'json',
-        'enable_utc': True,
+        "task_serializer": "json",
+        "result_serializer": "json",
+        "enable_utc": True,
     }
 
     conf_freezed = False
@@ -83,22 +83,22 @@ class CWCelery(Celery):
         self.cwconfig = cwconfig
 
         celery_config = self.defaults.copy()
-        if cwconfig.mode == 'test':
-            celery_config['task_always_eager'] = True
-            celery_config['task_eager_propagates'] = True
+        if cwconfig.mode == "test":
+            celery_config["task_always_eager"] = True
+            celery_config["task_eager_propagates"] = True
 
         if self.conf_freezed:
             return
 
         if cwconfig.apphome is not None:
-            fpath = osp.join(cwconfig.apphome, 'celeryconfig.py')
+            fpath = osp.join(cwconfig.apphome, "celeryconfig.py")
             if osp.isfile(fpath):
-                with open(fpath, 'rb') as fobj:
+                with open(fpath, "rb") as fobj:
                     exec(fobj.read(), celery_config)
         self.config_from_object(celery_config)
 
     def cwtask(self, *args, **opts):
-        opts.setdefault('bind', True)
+        opts.setdefault("bind", True)
         if len(args) == 1:
             return self.task(**opts)(args[0])
         return self.task(*args, **opts)
@@ -107,16 +107,17 @@ class CWCelery(Celery):
 app = CWCelery()
 
 options = [
-    Option(("-i", "--instance"),
-           prompt=True,
-           prompt_required=True,
-           help="Cubicweb instance name."),
-    Option(("--debug",),
-           default=False,
-           help="Enable cubicweb debug mode.")]
+    Option(
+        ("-i", "--instance"),
+        prompt=True,
+        prompt_required=True,
+        help="Cubicweb instance name.",
+    ),
+    Option(("--debug",), default=False, help="Enable cubicweb debug mode."),
+]
 
 for option in options:
-    app.user_options['preload'].add(option)
+    app.user_options["preload"].add(option)
 
 user_options = {}
 
@@ -131,12 +132,10 @@ def init_repo(cwconfig):
 @signals.user_preload_options.connect
 def on_preload_parsed(options, **kwargs):
     global user_options
-    user_options.update({
-        'instance': options['instance'],
-        'debug': options['debug']
-    })
+    user_options.update({"instance": options["instance"], "debug": options["debug"]})
     cwconfig = cwcfg.config_for(
-        user_options['instance'], debugmode=user_options['debug'])
+        user_options["instance"], debugmode=user_options["debug"]
+    )
 
     # load the repo
     repo = app.cwrepo = init_repo(cwconfig)
@@ -144,7 +143,7 @@ def on_preload_parsed(options, **kwargs):
     # setting up the app.
     # Any cube depending on the celery cube may update the configuration
     # in its registration callback.
-    if 'celery' not in repo.get_cubes():
+    if "celery" not in repo.get_cubes():
         raise ValueError("The 'celery' cube must be installed in the instance")
 
 
@@ -154,9 +153,10 @@ def on_worker_process_init(**kw):
 
     global user_options
     cwconfig = cwcfg.config_for(
-        user_options['instance'], debugmode=user_options['debug'])
+        user_options["instance"], debugmode=user_options["debug"]
+    )
 
     # Prevent cubes from modifying the configuration
     app.freeze_conf()
     repo = app.cwrepo = init_repo(cwconfig)
-    repo.hm.call_hooks('server_startup', repo=repo)
+    repo.hm.call_hooks("server_startup", repo=repo)
